pub struct ConfigValueGroup {
pub size_bytes: u64,
}Expand description
ConfigValueGroup struct containing all configurable values
Fields
size_bytes: u64Default chunk cache capacity: 10 GB or 0 depends on the build feature
Use the environment variable HF_XET_CHUNK_CACHE_SIZE_BYTES to set this value.
Implementations
Sourceimpl ConfigValueGroup
impl ConfigValueGroup
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new instance with default values only (no environment variable overrides).
Sourcepub fn apply_env_overrides(&mut self)
pub fn apply_env_overrides(&mut self)
Apply environment variable overrides to this configuration group.
The group name is derived from the module path. For example, in module xet_config::groups::data,
the env var for TEST_INT would be HF_XET_DATA_TEST_INT.
Sourcepub fn field_names() -> &'static [&'static str]
pub fn field_names() -> &'static [&'static str]
Returns the list of field names in this configuration group.