pub struct ConfigValueGroup {
pub nranges_in_streaming_fragmentation_estimator: usize,
pub min_n_chunks_per_range_hysteresis_factor: f32,
pub min_n_chunks_per_range: f32,
pub global_dedup_query_enabled: bool,
}Expand description
ConfigValueGroup struct containing all configurable values
Fields
nranges_in_streaming_fragmentation_estimator: usizeNumber of ranges to use when estimating fragmentation
The default value is 128.
Use the environment variable HF_XET_DEDUPLICATION_NRANGES_IN_STREAMING_FRAGMENTATION_ESTIMATOR to set this value.
min_n_chunks_per_range_hysteresis_factor: f32Minimum number of chunks per range. Used to control fragmentation This targets an average of 1MB per range. The hysteresis factor multiplied by the target Chunks Per Range (CPR) controls the low end of the hysteresis range. Basically, dedupe will stop when CPR drops below hysteresis * target_cpr, and will start again when CPR increases above target CPR.
The default value is 0.5.
Use the environment variable HF_XET_DEDUPLICATION_MIN_N_CHUNKS_PER_RANGE_HYSTERESIS_FACTOR to set this value.
min_n_chunks_per_range: f32Minimum number of chunks per range.
The default value is 8.0.
Use the environment variable HF_XET_DEDUPLICATION_MIN_N_CHUNKS_PER_RANGE to set this value.
global_dedup_query_enabled: boolWhether to enable global deduplication queries to the server. When enabled, the system will query the server for deduplication shards based on chunk hashes to enable cross-repository deduplication.
The default value is true.
Use the environment variable HF_XET_DEDUPLICATION_GLOBAL_DEDUP_QUERY_ENABLED to set this value.
Implementations
Sourceimpl ConfigValueGroup
impl ConfigValueGroup
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new instance with default values only (no environment variable overrides).
Sourcepub fn apply_env_overrides(&mut self)
pub fn apply_env_overrides(&mut self)
Apply environment variable overrides to this configuration group.
The group name is derived from the module path. For example, in module xet_config::groups::data,
the env var for TEST_INT would be HF_XET_DATA_TEST_INT.
Sourcepub fn field_names() -> &'static [&'static str]
pub fn field_names() -> &'static [&'static str]
Returns the list of field names in this configuration group.