Module runtime

Module runtime 

Structs

XetRuntime
This module provides a simple wrapper around Tokio’s runtime to create a thread pool with some default settings. It is intended to be used as a singleton thread pool for the entire application.

Enums

RuntimeMode
Whether the runtime owns its tokio thread pool or wraps an external handle.

Functions

check_sigint_shutdown
Quick function to check for a sigint shutdown.