PrivilegedExecutionContext

Enum PrivilegedExecutionContext 

pub enum PrivilegedExecutionContext {
    Regular,
    Elevated,
}

Variants



Regular



Elevated

Implementations

Source

impl PrivilegedExecutionContext

pub fn current() -> PrivilegedExecutionContext

pub fn is_elevated(&self) -> bool

pub fn create_dir_all(&self, path: impl AsRef<Path>) -> Result<()>

Recursively create a directory and all of its parent components if they are missing for write. If the current process is running with elevated privileges, the entries created will inherit permission from the path parent.

pub fn create_file(&self, path: impl AsRef<Path>) -> Result<File>

Open or create a file for write. If the current process is running with elevated privileges, the entries created will inherit permission from the path parent.