pub struct SafeFileCreator { /* private fields */ }Implementations
Sourceimpl SafeFileCreator
impl SafeFileCreator
Sourcepub fn new<P: AsRef<Path>>(dest_path: P) -> Result<Self>
pub fn new<P: AsRef<Path>>(dest_path: P) -> Result<Self>
Safely creates a new file at a specific location. Ensures the file is not created with elevated privileges, and a temporary file is created then renamed on close.
Sourcepub fn new_unnamed(temp_root: impl AsRef<Path>) -> Result<Self>
pub fn new_unnamed(temp_root: impl AsRef<Path>) -> Result<Self>
Safely creates a new file while a destination name can’t be decided now. Users need to call
ⓘ
pub fn set_dest_path<P: AsRef<Path>>(dest_path: P)to set the destination before closing the file.
Sourcepub fn replace_existing<P: AsRef<Path>>(dest_path: P) -> Result<Self>
pub fn replace_existing<P: AsRef<Path>>(dest_path: P) -> Result<Self>
Safely replaces a new file at a specific location. Ensures the file is not created with elevated privileges, and additionally the metadata of the old one will match the new metadata.
pub fn set_dest_path<P: AsRef<Path>>(&mut self, dest_path: P)
pub fn abort(&mut self) -> Result<()>