Module logging

Module logging 

Re-exports

pub use system_monitor::SystemMonitor;

Modules

system_monitor

Structs

LogDirConfig
The log directory cleanup configuration. By default, the values are loaded from environment variables.
LoggingConfig

Enums

LoggingMode

Functions

init
The main entry point to set up logging. Should only be called once.
wait_for_log_directory_cleanup
Wait for the log directory cleanup to complete. This function blocks until the background cleanup thread finishes.