pub struct HIGH_PERFORMANCE { /* private fields */ }Expand description
To set the high performance mode to true, set either of the following environment variables to 1 or true:
- HF_XET_HIGH_PERFORMANCE
- HF_XET_HP