ResultError

Trait ResultError 

pub trait ResultError:
    Send
    + Debug
    + Sync { }
Indicates the Error type for a singleflight Group. The response might have been generated on a separate thread, thus, we need this type to be Send + Sync.

Implementors

Source

impl<E: Send + Debug + Sync> ResultError for E