ResultType

Trait ResultType 

pub trait ResultType:
    Send
    + Clone
    + Sync
    + Debug { }
ResultType indicates the success type for a singleflight Group. Since the actual processing might occur on a separate thread, we need to type to be Send + Sync. It also needs to be Clone so that we can clone the response across many tasks

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T: Send + Clone + Sync + Debug> ResultType for T