pub struct ConfigValueGroup {
pub compression_scheme_retest_interval: usize,
pub compression_policy: ConfigEnum,
pub simulation_max_bytes: Option<ByteSize>,
pub simulation_max_chunks: Option<usize>,
}Expand description
ConfigValueGroup struct containing all configurable values
Fields
compression_scheme_retest_interval: usizeHow often should we retest the compression scheme? Determining the optimal compression scheme takes time, but it also minimizes the storage costs of the data.
If set to zero, it’s set once per file block per xorb.
The default value is 32.
Use the environment variable HF_XET_XORB_COMPRESSION_SCHEME_RETEST_INTERVAL to set this value.
compression_policy: ConfigEnumCompression policy for xorb data. Valid values: “” or “auto” for automatic detection, “none”, “lz4”, “bg4-lz4”. When set to “” or “auto”, the best compression scheme is chosen based on data analysis.
The default value is “auto” (auto-detect).
Use the environment variable HF_XET_XORB_COMPRESSION_POLICY to set this value.
simulation_max_bytes: Option<ByteSize>Override the maximum xorb size in bytes for simulation mode. When set to Some(value), this overrides the hard-coded MAX_XORB_BYTES cutting threshold in simulation builds. When None (default), the standard constant is used.
Only effective when the simulation feature is enabled.
Use the environment variable HF_XET_XORB_SIMULATION_MAX_BYTES to set this value.
simulation_max_chunks: Option<usize>Override the maximum xorb chunk count for simulation mode. When set to Some(value), this overrides the hard-coded MAX_XORB_CHUNKS cutting threshold in simulation builds. When None (default), the standard constant is used.
Only effective when the simulation feature is enabled.
Use the environment variable HF_XET_XORB_SIMULATION_MAX_CHUNKS to set this value.
Implementations
Sourceimpl ConfigValueGroup
impl ConfigValueGroup
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new instance with default values only (no environment variable overrides).
Sourcepub fn apply_env_overrides(&mut self)
pub fn apply_env_overrides(&mut self)
Apply environment variable overrides to this configuration group.
The group name is derived from the module path. For example, in module xet_config::groups::data,
the env var for TEST_INT would be HF_XET_DATA_TEST_INT.
Sourcepub fn field_names() -> &'static [&'static str]
pub fn field_names() -> &'static [&'static str]
Returns the list of field names in this configuration group.