Structs
- XetRuntime
- This module provides a simple wrapper around Tokio’s runtime to create a thread pool with some default settings. It is intended to be used as a singleton thread pool for the entire application.
Enums
- Runtime
Mode - Whether the runtime owns its tokio thread pool or wraps an external handle.
Functions
- check_
sigint_ shutdown - Quick function to check for a sigint shutdown.