Re-exports
pub use system_monitor::SystemMonitor;
Modules
Structs
- LogDir
Config - The log directory cleanup configuration. By default, the values are loaded from environment variables.
- Logging
Config
Enums
Functions
- init
- The main entry point to set up logging. Should only be called once.
- wait_
for_ log_ directory_ cleanup - Wait for the log directory cleanup to complete. This function blocks until the background cleanup thread finishes.