ResultError

Trait ResultError 

pub trait ResultError:
    Send
    + Debug
    + Sync { }
Indicates the Error type for a singleflight Group. The response might have been generated on a separate thread, thus, we need this type to be Send + Sync.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<E: Send + Debug + Sync> ResultError for E