pub trait TaskFuture<T, E>: Future<Output = Result<T, E>> + Send { }Expand description
Futures provided to a singleflight Group must produce a Result<T, E> for some T, E. This future must also be Send as it could be spawned as a tokio task.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".